@@ -21,6 +21,7 @@ class QTabWidget;
 class QTable;
 class QTextView;
 class QWidget;
+class fontPool;
 
 class infoDialog : public KDialogBase
 { 
@@ -46,7 +47,7 @@ public slots:
     /** This slot is called whenever anything in the fontpool has
         changed. If the infoDialog is shown, the dialog could then
         query the fontpool for more information. */
-    void       setFontInfo(class fontPool *fp);
+    void       setFontInfo(fontPool *fp);
 
     /** Calling this slot clears the text view and stores the
 	headline. The next time output is received via the
