@@ -9,16 +9,15 @@
 #include <kparts/browserextension.h>
 #include <kparts/factory.h>
 
-
+class KPrinter;
+class OptionDialog;
 class QLabel;
 class QPainter;
-class OptionDialog;
-
-
-#include <kmultipage.h>
 
 
+#include "../kviewshell/kmultipage.h"
 #include "dviwin.h"
+#include "history.h"
 
 
 class KDVIMultiPageFactory : public KParts::Factory
@@ -30,14 +29,13 @@ public:
   KDVIMultiPageFactory();
   virtual ~KDVIMultiPageFactory();
 
-  virtual KParts::Part *createPart( QWidget *parentWidget, const char *widgetName, QObject *parent, const char *name, const char *, const QStringList & );
+  virtual KParts::Part *createPartObject( QWidget *parentWidget, const char *widgetName, QObject *parent, const char *name, const char *, const QStringList & );
 
   static KInstance *instance();
 
 private:
 
   static KInstance *s_instance;
-
 };
 
 
@@ -49,7 +47,10 @@ public:
 
   KDVIMultiPage(QWidget *parentWidget, const char *widgetName, QObject *parent, const char *name);
   virtual ~KDVIMultiPage();
-
+  // Methods which are associated with the DCOP functionality of the
+  // kmultipage. This method can be implemented by the multipage,
+  // e.g. to jump to a certain location.
+  void  jumpToReference(QString reference);
 
 // Interface definition start ------------------------------------------------
 
@@ -81,6 +82,8 @@ public:
   virtual bool print(const QStringList &pages, int current);
 
 protected:
+  history document_history;
+
   /// For internal use only. See the comments in kdvi_multipage.cpp, right
   //before the timerEvent function.
   int  timer_id;
@@ -93,34 +96,57 @@ protected:
 
 signals:
 
-  /// Emitted to indicate the number of pages in the file. The
-  //receiver will set the current page to zero and call the
-  //gotoPage()-method.
+  /** Emitted to indicate the number of pages in the file. The
+      receiver will set the current page to zero and call the
+      gotoPage()-method. */
   void numberOfPages(int nr);
 
-  /// Emitted to indicate the number of pages in the file and the
-  //current page. The receiver will not change or update the display,
-  //nor call the gotoPage()-method.
+  /** Emitted to indicate the number of pages in the file and the
+      current page. The receiver will not change or update the
+      display, nor call the gotoPage()-method. */
   void pageInfo(int nr, int currpg);
 
 protected slots:
-
   void doSettings();
+  void doInfo();
+  void doExportPS();
+  void doExportPDF();
+  void doExportText();
+  void doSelectAll();
+  void doGoBack();
+  void doGoForward();
+  void doEnableWarnings();
   void about();
   void helpme();
   void bugform();
   void preferencesChanged();
   void goto_page(int page, int y);
-
+  void contents_of_dviwin_changed(void);
+  void showTip(void);
+  void showTipOnStart(void);
 
 private:
-
-  dviWindow *window;
+  dviWindow    *window;
   OptionDialog *options;
+  KPrinter     *printer;
 
+  /** Pointers to several actions which are disabled if no file is
+      loaded. */
+  KAction      *docInfoAction;
+  KAction      *backAction;
+  KAction      *forwardAction;
+  KAction      *copyTextAction;
+  KAction      *selectAllAction;
+  KAction      *findTextAction;
+  KAction      *findNextTextAction;
+  KAction      *exportPSAction;
+  KAction      *exportPDFAction;
+  KAction      *exportTextAction;
+
+  /** Used to enable the export menu when a file is successfully
+      loaded. */
+  void enableActions(bool);
 };
 
 
 #endif
-
-
