@@ -1,6 +1,6 @@
    /*
 
-    $Id: kfax.cpp,v 1.79 2002/08/11 21:54:06 nhasan Exp $
+    $Id: kfax.cpp,v 1.79.2.2 2003/05/15 11:28:19 waba Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -33,7 +33,6 @@
 
 #include <qfile.h>
 #include <qstrlist.h>
-#include <qdragobject.h>
 #include <qtimer.h>
 
 #include <klocale.h>
@@ -51,6 +50,7 @@
 #include <ktempfile.h>
 #include <kstdaction.h>
 #include <kdebug.h>
+#include <kurldrag.h>
 
 #include "kfax.h"
 #include "kfax.moc"
@@ -941,22 +941,21 @@ void TopLevel::openNetFile( const KURL &u)
   }
 }
 
+void TopLevel::dragEnterEvent( QDragEnterEvent * event)
+{
+  event->accept(KURLDrag::canDecode(event));
+}
+
 void TopLevel::dropEvent( QDropEvent * event)
 {
 
-  QStrList list;
-  QUriDrag::decode(event, list);
-
-  const char *s = list.first();
-
-  if(s != 0L)
+  KURL::List list;
+  
+  if (KURLDrag::decode(event, list) && !list.isEmpty())
   {
     // Load the first file in this window
-    if ( s == list.getFirst() )
-    {
-      QString n = s;
-      openNetFile( n );
-    }
+    const KURL &url = list.first();
+    openNetFile( url );
   }
 }
 
@@ -1606,6 +1605,7 @@ void TopLevel::uiUpdate(){
       typestring += "G4";
 
     statusbar->changeItem(typestring,ID_TYPE);
+    updateActions();
   }
 }
 
